@@ -4,21 +4,25 @@
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
     SPDX-FileCopyrightText: 2016 Andre Heinecke <aheinecke@gnupg.org>
+    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "useridlistmodel.h"
-#include "utils/formatting.h"
+#include <config-libkleo.h>
 
-#include <gpgme++/key.h>
+#include "useridlistmodel.h"
+
+#include "keycache.h"
+#include "utils/formatting.h"
 
 #include <KLocalizedString>
 
 #include <QVariant>
 #include <QIcon>
 
-#include "keycache.h"
+#include <gpgme++/key.h>
 
 #include <gpgme++/gpgmepp_version.h>
 #if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
@@ -39,6 +43,8 @@ class UIDModelItem
     //
 public:
     explicit UIDModelItem(const UserID::Signature &sig, UIDModelItem *parentItem, bool showRemarks)
+        : mParentItem{parentItem}
+        , mSig{sig}
     {
         mItemData  << QString::fromUtf8(sig.signerKeyID())
                    << Formatting::prettyName(sig)
@@ -47,29 +53,31 @@ public:
                    << Formatting::expirationDateString(sig)
                    << Formatting::validityShort(sig)
                    << (sig.isExportable() ? QStringLiteral("✓") : QString());
-        mSig = sig;
-        mParentItem = parentItem;
 
+        QString lastNotation;
         if (showRemarks && parentItem) {
-            QString lastNotation;
             for (const auto &notation: sig.notations()) {
                 if (notation.name() && !strcmp(notation.name(), "rem@gnupg.org")) {
                     lastNotation = QString::fromUtf8(notation.value());
                 }
             }
-            mItemData << lastNotation;
         }
+        mItemData << lastNotation;
+
+#ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
+        mItemData << Formatting::trustSignatureDomain(sig);
+#endif
     }
 
     explicit UIDModelItem(const UserID &uid, UIDModelItem *parentItem)
+        : mParentItem{parentItem}
+        , mUid{uid}
     {
         mItemData << Formatting::prettyUserID(uid);
-        mUid = uid;
-        mParentItem = parentItem;
     }
 
     // The root item
-    explicit UIDModelItem(bool showRemarks) : mParentItem(nullptr)
+    UIDModelItem()
     {
         mItemData << i18n("ID")
                   << i18n("Name")
@@ -77,11 +85,11 @@ public:
                   << i18n("Valid From")
                   << i18n("Valid Until")
                   << i18n("Status")
-                  << i18n("Exportable");
-
-        if (showRemarks) {
-            mItemData << i18n("Tags");
-        }
+                  << i18n("Exportable")
+                  << i18n("Tags");
+#ifdef GPGMEPP_SUPPORTS_TRUST_SIGNATURES
+        mItemData << i18n("Trust Signature For");
+#endif
     }
 
     ~UIDModelItem()
@@ -127,18 +135,22 @@ public:
 
     QVariant toolTip(int column) const
     {
-        if (column == 5 /*Status*/) {
-            return i18n("class %1", mSig.certClass());
+        if (!mSig.isNull()) {
+            if (column == static_cast<int>(UserIDListModel::Column::Status)) {
+                return i18n("class %1", mSig.certClass());
+            } else if (column == static_cast<int>(UserIDListModel::Column::TrustSignatureDomain)) {
+                return Formatting::trustSignature(mSig);
+            }
         }
         return mItemData.value(column);
     }
 
     QVariant icon(int column) const
     {
-        if (!mSig.isNull() && column == 5 /*Status*/) {
+        if (!mSig.isNull() && column == static_cast<int>(UserIDListModel::Column::Status)) {
             return Formatting::validityIcon(mSig);
         }
-        return QVariant();
+        return {};
     }
 
     int row() const
@@ -173,14 +185,11 @@ private:
 };
 
 UserIDListModel::UserIDListModel(QObject *p)
-    : QAbstractItemModel(p), mRootItem(nullptr)
+    : QAbstractItemModel{p}
 {
 }
 
-UserIDListModel::~UserIDListModel()
-{
-    delete mRootItem;
-}
+UserIDListModel::~UserIDListModel() = default;
 
 Key UserIDListModel::key() const
 {
@@ -190,13 +199,12 @@ Key UserIDListModel::key() const
 void UserIDListModel::setKey(const Key &key)
 {
     beginResetModel();
-    delete mRootItem;
     mKey = key;
 
-    mRootItem = new UIDModelItem(mRemarksEnabled);
+    mRootItem.reset(new UIDModelItem);
     for (int i = 0, ids = key.numUserIDs(); i < ids; ++i) {
         UserID uid = key.userID(i);
-        auto uidItem = new UIDModelItem(uid, mRootItem);
+        auto uidItem = new UIDModelItem(uid, mRootItem.get());
         mRootItem->appendChild(uidItem);
         std::vector<UserID::Signature> sigs = uid.signatures();
 #ifdef GPGME_USERID_SIGNATURES_ARE_SORTABLE
@@ -226,17 +234,11 @@ int UserIDListModel::columnCount(const QModelIndex &parent) const
 
 int UserIDListModel::rowCount(const QModelIndex &parent) const
 {
-    UIDModelItem *parentItem = nullptr;
     if (parent.column() > 0 || !mRootItem) {
         return 0;
     }
 
-    if (!parent.isValid()) {
-        parentItem = mRootItem;
-    } else {
-        parentItem = static_cast<UIDModelItem*>(parent.internalPointer());
-    }
-
+    const UIDModelItem *const parentItem = !parent.isValid() ? mRootItem.get() : static_cast<UIDModelItem*>(parent.internalPointer());
     return parentItem->childCount();
 }
 
@@ -246,15 +248,8 @@ QModelIndex UserIDListModel::index(int row, int column, const QModelIndex &paren
         return {};
     }
 
-    UIDModelItem *parentItem = nullptr;
-
-    if (!parent.isValid()) {
-        parentItem = mRootItem;
-    } else {
-        parentItem = static_cast<UIDModelItem*>(parent.internalPointer());
-    }
-
-    UIDModelItem *childItem = parentItem->child(row);
+    const UIDModelItem *const parentItem = !parent.isValid() ? mRootItem.get() : static_cast<UIDModelItem*>(parent.internalPointer());
+    UIDModelItem *const childItem = parentItem->child(row);
     if (childItem) {
         return createIndex(row, column, childItem);
     } else {
@@ -270,7 +265,7 @@ QModelIndex UserIDListModel::parent(const QModelIndex &index) const
     auto childItem = static_cast<UIDModelItem*>(index.internalPointer());
     UIDModelItem *parentItem = childItem->parentItem();
 
-    if (parentItem == mRootItem) {
+    if (parentItem == mRootItem.get()) {
         return QModelIndex();
     }
 
@@ -320,10 +315,10 @@ UserID UserIDListModel::userID(const QModelIndex& index) const
     return item->uid();
 }
 
-QVector<UserID> UserIDListModel::userIDs(const QModelIndexList &indexs) const
+QVector<UserID> UserIDListModel::userIDs(const QModelIndexList &indexes) const
 {
     QVector<GpgME::UserID> ret;
-    for (const QModelIndex &idx : indexs) {
+    for (const QModelIndex &idx : indexes) {
         if (!idx.isValid()) {
             continue;
         }
@@ -344,10 +339,10 @@ UserID::Signature UserIDListModel::signature(const QModelIndex& index) const
     return item->signature();
 }
 
-QVector<UserID::Signature> UserIDListModel::signatures(const QModelIndexList &indexs) const
+QVector<UserID::Signature> UserIDListModel::signatures(const QModelIndexList &indexes) const
 {
     QVector<GpgME::UserID::Signature> ret;
-    for (const QModelIndex &idx : indexs) {
+    for (const QModelIndex &idx : indexes) {
         if (!idx.isValid()) {
             continue;
         }
